@@ -61,7 +61,7 @@ except ImportError:
 
 try:
     import dbus
-    from dbus import SystemBus, lowlevel
+    from dbus import SystemBus, lowlevel, SessionBus
     dbus_avail=True
 except ImportError:
     dbus_avail=False
@@ -107,23 +107,21 @@ ERROR_DIGITAL_SIGN_BAD =3
 MAJ_VER = sys.version_info[0]
 MIN_VER = sys.version_info[1]
 
-
-
 EXPECT_WORD_LIST = [
     pexpect.EOF, # 0
     pexpect.TIMEOUT, # 1
-    "Continue?", # 2 (for zypper)
-    "passwor[dt]:", # en/de/it/ru
-    "kennwort", # de?
-    "password for", # en
-    "mot de passe", # fr
-    "contraseña", # es
-    "palavra passe", # pt
-    "口令", # zh
-    "wachtwoord", # nl
-    "heslo", # czech
-    "密码",
-    "Lösenord", #sv
+    u"Continue?", # 2 (for zypper)
+    u"passwor[dt]:", # en/de/it/ru
+    u"kennwort", # de?
+    u"password for", # en
+    u"mot de passe", # fr
+    u"contraseña", # es
+    u"palavra passe", # pt
+    u"口令", # zh
+    u"wachtwoord", # nl
+    u"heslo", # czech
+    u"密码",
+    u"Lösenord", #sv
 ]
 
 
@@ -713,9 +711,15 @@ def canEnterGUIMode4(): # qt4
         log.warn("No display found.")
         return False
 
-    elif not checkPyQtImport4():
-        log.warn("Qt/PyQt 4 initialization failed.")
-        return False
+    # elif not checkPyQtImport4():
+    #     log.warn("Qt4/PyQt 4 initialization failed.")
+    #     return False
+    else:
+        try:
+            checkPyQtImport45()
+        except ImportError as e:
+            log.warn(e)
+            return False
 
     return True
 
@@ -776,10 +780,22 @@ def checkPyQtImport4():
         import PyQt4
         import ui4
     except ImportError:
-        log.error("HPLIP is not installed properly or is installed without graphical support. Please reinstall HPLIP")
-        return False
+        import PyQt5
+        import ui5
     else:
-        return True
+        log.debug("HPLIP is not installed properly or is installed without graphical support. Please reinstall HPLIP again")
+        return False
+    return True
+
+# def checkPyQtImport5():
+#     try:
+#         import PyQt5
+#         import ui5
+#     except ImportError:
+#         log.error("HPLIP is not installed properly or is installed without graphical support PyQt5. Please reinstall HPLIP")
+#         return False
+#     else:
+#         return True
 
 
 try:
@@ -1259,6 +1275,17 @@ def run(cmd, passwordObj = None, pswd_msg='', log_output=True, spinner=True, tim
     import io
     output = io.StringIO()
 
+    pwd_prompt_str = ""
+    if passwordObj and ('su' in cmd or 'sudo' in cmd) and os.geteuid() != 0:
+        pwd_prompt_str = passwordObj.getPasswordPromptString()
+        log.debug("cmd = %s pwd_prompt_str = [%s]"%(cmd, pwd_prompt_str))
+        if(pwd_prompt_str == ""):
+            passwd = passwordObj.getPassword(pswd_msg, 0)
+            pwd_prompt_str = passwordObj.getPasswordPromptString()
+            log.debug("pwd_prompt_str2 = [%s]"%(pwd_prompt_str))
+            if(passwd == ""):
+               return 127, ""
+
     try:
         child = pexpect.spawnu(cmd, timeout=timeout)
     except pexpect.ExceptionPexpect as e:
@@ -1276,15 +1303,22 @@ def run(cmd, passwordObj = None, pswd_msg='', log_output=True, spinner=True, tim
                 continue
 
             if child.before:
+                if(pwd_prompt_str and pwd_prompt_str not in EXPECT_LIST):
+                    log.debug("Adding %s to EXPECT LIST"%pwd_prompt_str)
+                    try:
+                        p = re.compile(pwd_prompt_str, re.I)
+                    except TypeError:
+                        EXPECT_LIST.append(pwd_prompt_str)
+                    else:
+                        EXPECT_LIST.append(p)
+                        EXPECT_LIST.append(pwd_prompt_str)
+
                 try:
                     output.write(child.before)
+                    if log_output:
+                        log.debug(child.before)
                 except Exception:
                     pass
-                if log_output:
-                    try:
-                        log.debug(child.before)
-                    except Exception:
-                        pass
 
             if i == 0: # EOF
                 break
@@ -1550,10 +1584,15 @@ USAGE_INTERACTIVE_MODE = ("Run in interactive mode:", "-i or --interactive", "op
 if sys_conf.get('configure', 'ui-toolkit', 'qt3') == 'qt3':
     USAGE_USE_QT3 = ("Use Qt3:",  "--qt3 (Default)",  "option",  False)
     USAGE_USE_QT4 = ("Use Qt4:",  "--qt4",  "option",  False)
-else:
+    USAGE_USE_QT5 = ("Use Qt5:",  "--qt5",  "option",  False)
+elif sys_conf.get('configure', 'ui-toolkit', 'qt4') == 'qt4':
     USAGE_USE_QT3 = ("Use Qt3:",  "--qt3",  "option",  False)
     USAGE_USE_QT4 = ("Use Qt4:",  "--qt4 (Default)",  "option",  False)
-
+    USAGE_USE_QT5 = ("Use Qt5:",  "--qt5",  "option",  False)
+elif sys_conf.get('configure', 'ui-toolkit', 'qt5') == 'qt5':
+    USAGE_USE_QT3 = ("Use Qt3:",  "--qt3",  "option",  False)
+    USAGE_USE_QT4 = ("Use Qt4:",  "--qt4",  "option",  False)
+    USAGE_USE_QT5 = ("Use Qt5:",  "--qt5 (Default)",  "option",  False)
 
 def ttysize(): # TODO: Move to base/tui
     ln1 = subprocess.getoutput('stty -a').splitlines()[0]
@@ -2018,7 +2057,7 @@ def download_from_network(weburl, outputFile = None, useURLLIB=False):
 
             if useURLLIB:
 		
-                sys.stdout.write("Download in progress..........")
+                #sys.stdout.write("Download in progress..........")
                 try:
                     response = urllib2_request.urlopen(weburl)    
                     file_fd = open(outputFile, 'wb')
@@ -2067,7 +2106,7 @@ def sendEvent(event_code,device_uri, printer_name, username="", job_id=0, title=
 
     log.debug("send_message() entered")
     args = [device_uri, printer_name, event_code, username, job_id, title, pipe_name]
-    msg = lowlevel.SignalMessage('/', DBUS_SERVICE, 'Event')
+    msg = lowlevel.SignalMessage(path='/', interface=DBUS_SERVICE, name='Event')
     msg.append(signature='ssisiss', *args)
     SystemBus().send_message(msg)
     log.debug("send_message() returning")
@@ -2382,3 +2421,59 @@ def extract_xml_chunk(data):
             data = data[index+2+size+2:len(data)]
         data = temp
     return data
+
+
+def checkPyQtImport45():
+    try:
+        import PyQt5
+        return "PyQt5"
+    except ImportError as e:
+        log.debug(e)
+
+    try:
+        import PyQt4
+        return "PyQt4"
+    except ImportError as e:
+        log.debug(e)
+
+    raise ImportError("GUI Modules PyQt4 and PyQt5 are not installed")
+
+
+def ui_status():
+    _ui_status = ""
+    try:
+        _ui_status = checkPyQtImport45()
+        log.note("Using GUI Module %s" % _ui_status)
+        return _ui_status
+    except ImportError as e:
+        log.error(e)
+
+
+def import_dialog(ui_toolkit):
+    if ui_toolkit == "qt4":
+        try:
+            from PyQt4.QtGui import QApplication
+            log.debug("Using PyQt4")
+            return  (QApplication, "ui4")
+        except ImportError as e:
+            log.error(e)
+            sys.exit(1)
+    elif ui_toolkit == "qt5":
+        try:
+            from PyQt5.QtWidgets import QApplication
+            log.debug("Using PyQt5")
+            return (QApplication, "ui5")
+        except ImportError as e:
+            log.error(e)
+            sys.exit(1)
+        else:
+            log.error("Unable to load Qt support. Is it installed?")
+            sys.exit(1)
+
+
+def dyn_import_mod(mod_name_as_str):
+    components = mod_name_as_str.split('.')
+    mod = __import__(mod_name_as_str)
+    for comp in components[1:]:
+        mod = getattr(mod, comp)
+    return mod
