@@ -38,6 +38,12 @@ from base.g import *
 from base import device, utils, maint, tui, module
 from prnt import cups
 
+try:
+    from importlib import import_module
+except ImportError as e:
+    log.debug(e)
+    from base.utils import dyn_import_mod as import_module
+
 
 def CleanUIx(level):
     global d
@@ -105,7 +111,7 @@ def CleanUI3(msg =""):
 
 try:
     mod = module.Module(__mod__, __title__, __version__, __doc__, None,
-                        (INTERACTIVE_MODE, GUI_MODE), (UI_TOOLKIT_QT4,))
+                        (INTERACTIVE_MODE, GUI_MODE), (UI_TOOLKIT_QT4, UI_TOOLKIT_QT5))
 
     mod.setUsage(module.USAGE_FLAG_DEVICE_ARGS,
                  see_also_list=['hp-align', 'hp-clean', 'hp-linefeedcal',
@@ -185,18 +191,15 @@ try:
             d.close()
 
     else:
-        try:
-            from PyQt4.QtGui import QApplication
-            from ui4.cleandialog import CleanDialog
-        except ImportError:
-            log.error("Unable to load Qt4 support. Is it installed?")
-            sys.exit(1)
+
+        QApplication, ui_package = utils.import_dialog(ui_toolkit)
+        ui = import_module(ui_package + ".cleandialog")
 
 
         #try:
         if 1:
             app = QApplication(sys.argv)
-            dlg = CleanDialog(None, device_uri)
+            dlg = ui.CleanDialog(None, device_uri)
             dlg.show()
             try:
                 log.debug("Starting GUI loop...")
