@@ -43,7 +43,7 @@ from prnt import cups
 
 mod = module.Module(__mod__, __title__, __version__, __doc__, None,
                     (NON_INTERACTIVE_MODE, GUI_MODE),
-                    (UI_TOOLKIT_QT3, UI_TOOLKIT_QT4), False, False, True)
+                    (UI_TOOLKIT_QT3, UI_TOOLKIT_QT4, UI_TOOLKIT_QT5), False, False, True)
 
 mod.setUsage(module.USAGE_FLAG_DEVICE_ARGS,
     extra_options=[
