@@ -919,7 +919,7 @@ else: # INTERACTIVE_MODE
                 if len(path) > 0:
                     cmd = 'hp-testpage -i %s' % param
                 else:
-                    cmd = '/usr/local/bin/python2.7 ./testpage.py -i %s' % param
+                    cmd = '/usr/local/bin/python2.7 /usr/local/share/hplip/testpage.py -i %s' % param
 
                 os_utils.execute(cmd)
 
