@@ -33,12 +33,19 @@ import os
 import getopt
 import signal
 
+
 # Local
 from base.g import *
 #from . import base.utils as utils
 import base.utils as utils
 from base import status, tui, module
 
+try:
+    from importlib import import_module
+except ImportError as e:
+    log.debug(e)
+    from base.utils import dyn_import_mod as import_module
+
 
 w = None # write pipe
 app = None
@@ -66,7 +73,7 @@ def handle_session_signal(*args, **kwds):
 
 
 mod = module.Module(__mod__, __title__, __version__, __doc__, None,
-                    (GUI_MODE,), (UI_TOOLKIT_QT3, UI_TOOLKIT_QT4))
+                    (GUI_MODE,), (UI_TOOLKIT_QT3, UI_TOOLKIT_QT4, UI_TOOLKIT_QT5))
 mod.lockInstance()
 
 mod.setUsage(module.USAGE_FLAG_NONE,
@@ -240,14 +247,29 @@ if ui_toolkit == 'qt3':
         sys.exit(0)
 
 else: # qt4
-    try:
-        from PyQt4.QtGui import QApplication
+    # if utils.ui_status[1] == "PyQt4":
+    #     try:
+    #         from PyQt4.QtGui import QApplication
+    #         from ui4.devmgr5 import DevMgr5
+    #     except ImportError as e:
+    #         log.error(e)
+    #         sys.exit(1)
+    # elif utils.ui_status[1] == "PyQt5":
+    #     try:
+    #         from PyQt5.QtWidgets import QApplication
+    #         from ui5.devmgr5 import DevMgr5
+    #     except ImportError as e:
+    #         log.error(e)
+    #         import traceback
+    #         traceback.print_exc()
+    #         sys.exit(1)
+    # else:
+    #     log.error("Unable to load Qt support")
+    #     sys.exit(1)
+    QApplication, ui_package = utils.import_dialog(ui_toolkit)
+    ui = import_module(ui_package + ".devmgr5")
 
-    except ImportError:
-        log.error("Unable to load Qt4 support. Is it installed?")
-        sys.exit(1)
 
-    from ui4.devmgr5 import DevMgr5
 
     log.set_module("hp-toolbox(UI)")
 
@@ -255,7 +277,7 @@ else: # qt4
     #try:
         app = QApplication(sys.argv)
 
-        toolbox = DevMgr5(__version__, device_uri,  None)
+        toolbox = ui.DevMgr5(__version__, device_uri,  None)
         toolbox.show()
         try:
             log.debug("Starting GUI loop...")
